quantizationtools.tempo_scaled_rationals_to_q_events
====================================================

.. autofunction:: abjad.tools.quantizationtools.tempo_scaled_rationals_to_q_events.tempo_scaled_rationals_to_q_events
